@@ -59,8 +59,11 @@ from datetime import datetime
 import time
 from Exceptions import *
 from PyQt4.QtCore import *
+import osso
 
-g_orietation = 0
+from Controller import Controller
+
+g_orientation = 0
 
 
 #these are for testing
@@ -82,7 +85,9 @@ DEFAULT_AVATAR_FILE=ICONS_DIR+"default_avatar.jpg"
 VERIFIED_FILE=ICONS_DIR+"verified.png"
 
 COLOR_BACKGROUND="#edf1f2"
-COLOR_BACKGROUND_ALT="#e6eaeb"
+COLOR_BACKGROUND_ALT = "#e6eaeb"
+COLOR_BACKGROUND_USER = '#222222'
+COLOR_TEXT_HEAVY = '#7AB4F5'
 
 ROLE_AVATAR=99
 ROLE_TIME=98
@@ -103,6 +108,13 @@ ROLE_TEST_GAP=88
 ROLE_CM_NUM=83
 ROLE_RT_NUM=84
 ROLE_UNREAD = 82
+ROLE_FRIENDS = 81
+ROLE_FOLLOWERS = 80
+ROLE_LOCATION = 79
+ROLE_GENDER = 78
+ROLE_STATUSES = 77
+
+
 
 SETTINGS_ATT_NAMES=[
         "downpic",
@@ -191,7 +203,8 @@ USER_ATT_NAMES=[
         "favourites_count",
         "created_at",
         "following",
-        "verified"
+        "verified",
+        "avatar_large"
         ]
 
 ACCOUNT_ATT_NAMES=[
@@ -221,18 +234,35 @@ TIMELINE_TYPE_FAVOUR=5
 TIMELINE_TYPE_ST_COMMENTS=6
 TIMELINE_TYPE_UNREAD=7
 TIMELINE_TYPE_DEUNREAD=8
+TIMELINE_TYPE_USER_SHOW=9
+TIMELINE_TYPE_USER_TIMELINE=10
 
 NEW_A_STATUS=11
 
 
+settings = {}
+
+osso_c = None
+osso_rpc = None
+controller = None
+
+def init_osso_context(name):
+    global osso_c
+    osso_c = osso.Context(name,"0.0.1",False)
+    global osso_rpc
+    osso_rpc = osso.Rpc(osso_c)
+def init_controller():
+    global controller
+    controller = Controller()
 def build_menus():
-    menuString=["我的首页","提到我的","我的评论","我的广播","我的收藏","发表微博"]
+    menuString=["我的首页","提到我的","我的评论","我的广播","我的资料","发表微博"]
     menuValues=[TIMELINE_TYPE_FRIENDS,TIMELINE_TYPE_MENTIONS,
                          TIMELINE_TYPE_COMMENTS,TIMELINE_TYPE_DM,
                          TIMELINE_TYPE_FAVOUR,NEW_A_STATUS]
     menuIcons=[ICONS_DIR+"menu_home.png",ICONS_DIR+"menu_mention.png",
                ICONS_DIR+"menu_comment.png",ICONS_DIR+"menu_message.png",
-               ICONS_DIR+"menu_favorite.png",ICONS_DIR+"menu_compose.png"]
+               #ICONS_DIR+"menu_favorite.png",ICONS_DIR+"menu_compose.png"]
+               ICONS_DIR+"menu_info_hl@simple.png",ICONS_DIR+"menu_compose.png"]
     result = []
     for i in range(6):
         menu={}
@@ -308,6 +338,8 @@ def build_a_user_from_row(obj):
             result[att]=obj[att]
         except AttributeError:
             result[att]=None
+    
+    result["status"] = None        
     return result
 
 def build_an_empty_account():
@@ -413,6 +445,7 @@ def build_a_unread_count_from_obj_qq(obj):
         except:
             result[att]=0
             #print att, result[att]
+        result["followers"] = obj['fans']
     return result    
 
 
@@ -422,13 +455,25 @@ def dump(obj):
         print "obj.%s = %s" % (attr, getattr(obj, attr))
     
 def build_a_user_from_obj(obj,accountId):
+    #print "build_a_user_from_obj"
     result = {}
     for att in USER_ATT_NAMES:
         try:
-            result[att]=getattr(obj,att)
+            result[att]=getattr(obj,att) 
+            #print att,result[att]
         except AttributeError:
             result[att]=None
     result["account"]=accountId
+
+    try:
+        s=getattr(obj,"status")  
+        if s!=None:
+            sStatus=build_a_status_from_obj(s,accountId)
+            result["status"]=sStatus
+            #print "build_a_user_from_obj" + result["status"]["text"]
+    except AttributeError:
+        result["status"]=None
+    
     return result
 
 
@@ -503,20 +548,62 @@ def build_a_user_from_obj_qq(obj,accountId):
     
     result["province"]=""
     result["city"]=""
-    result["description"]=""
     result["url"]=""
     result["domain"]=""
-    result["gender"]=""
+
+    try:
+        result["description"]=obj["introduction"]
+    except:
+        result["description"]=""
+        
+    try:
+        if obj["sex"] == 1:
+           result["gender"]="m"
+        else:   
+           result["gender"]="f"
+    except:
+        result["gender"]="m"
+
+    try:
+        result["followers_count"]=obj['fansnum']
+    except:
+        result["followers_count"]=0
+    try:
+        result["friends_count"]=obj['idolnum']
+    except:
+        result["friends_count"]=0
+    try:
+        result["statuses_count"]=obj['tweetnum']
+    except:
+        result["statuses_count"]=0
     
-    result["followers_count"]=0
-    result["friends_count"]=0
-    result["statuses_count"]=0
     result["favourites_count"]=0
     
-    result["created_at"]=toDateTime(obj["timestamp"])
-    
+    try:
+        result["created_at"]=toDateTime(obj["timestamp"])
+    except:
+        result["created_at"]=None
+
+    try:
+        result["ismyfans"]=obj['ismyfans']
+    except:
+        result["ismyfans"]=0
+    try:
+        result["ismyidol"]=obj['ismyidol']
+    except:
+        result["ismyidol"]=0
+
     result["following"]=0
     result["verified"]=obj["isvip"]
+    result["avatar_large"]=None
+
+    try:
+       result["status"] = {}
+       result["status"]["text"] = obj["tweet"][0]["text"]
+       result["status"]["created_at"]=toDateTime(obj["tweet"][0]["timestamp"])
+    except:
+        result["status"] = None
+
     
     return result
 
@@ -734,6 +821,7 @@ CREATE TABLE [user]
 [created_at] DATETIME,
 [following] BOOLEAN,
 [verified] BOOLEAN,
+[avatar_large] VARCHAR,
 [account] INTEGER,
 [user_id] INTEGER PRIMARY KEY AUTOINCREMENT
 )
