@@ -1275,7 +1275,7 @@ class MaoboApp(QApplication):
         
         # append gps info.
         import os
-        ret = os.popen('python location.gps.py').read()
+        ret = os.popen('python /opt/maebo/location.gps.py').read()
         tmpParam = ret.split(',')
         print 'lat:' + tmpParam[0]
         print 'long:' + tmpParam[1]
