@@ -19,6 +19,8 @@ import re
 from qqweibo.error import QWeiboError
 from qqweibo.utils import convert_to_utf8_str
 
+from PyQt4.QtMaemo5 import QMaemo5InformationBox
+
 re_path_template = re.compile('{\w+}')
 
 
@@ -143,15 +145,15 @@ def bind_api(**config):
                         self.method, self.headers, self.parameters
                     )
                 try:
-                    #print str(time.time())+ " get/post " + url_full
+                    print str(time.time())+ " get/post " + url_full
                     if self.method == 'POST':
                         req = Request(url_full, data=self.post_data, headers=self.headers)
-                        #print str(time.time())+ " post data" + self.post_data
+                        print str(time.time())+ " post data" + self.post_data
                     else:
                         req = Request(url_full)
-                    #print str(time.time())+ "After Request"
+                    print str(time.time())+ "After Request"
                     resp = urlopen(req)
-                    #print str(time.time())+ "After urlopen"
+                    print str(time.time())+ "After urlopen"
                 except Exception, e:
                     raise QWeiboError("Failed to send request: %s url=%s headers=%s" % \
                                       (e, url, self.headers))
@@ -199,8 +201,9 @@ def bind_api(**config):
                 ret_code = -1                
                 error_msg = "Weibo error response: Error = %s" % e            
             finally:                
-                if ret_code!= 0:                    
+                if ret_code!= 0:
                     raise QWeiboError(error_msg)
+                    
 
             # Parse the response payload
             result = self.api.parser.parse(self, body)
@@ -210,6 +213,9 @@ def bind_api(**config):
                 self.api.cache.store(url, result)
             return result
 
+        def show_notice(self,message,timeout=QMaemo5InformationBox.DefaultTimeout):
+            QMaemo5InformationBox.information(None,"\n"+unicode(message)+"\n",timeout)
+            
     def _call(api, *args, **kargs):
 
         method = APIMethod(api, args, kargs)
